Part of the set of internal functions for estimating bootstrapped confidence intervals
for continuous outcome and two treatment groups when user argument CI="boot".
estBootCIs(trt, t.seq, M, Y, t.est, deltat, replicates)A list containing:
bootstrapped standard error for the estimated mediation effect
percentile bootstrapped CI upper limit for the estimated mediation effect
percentile bootstrapped CI lower limit for the estimated mediation effect
a vector indicating treatment group
a vector of time points at each obs
matrix of mediator values
matrix of outcome values
time points at which to make the estimation
a small constant which controls the time-lag of the effect of the mediator on the outcome, half the time between two time points
number of replicates for bootstrapping confidence intervals.